@@ -1,11 +1,14 @@
 package Moses::Plugin;
+BEGIN {
+  $Moses::Plugin::VERSION = '0.90';
+}
+# ABSTRACT: Sugar for Moses Plugins
+# Dist::Zilla: +PodWeaver
 use Moose       ();
 use MooseX::POE ();
 use Moose::Exporter;
 use Adam::Plugin;
 
-our $VERSION = $Adam::VERSION;
-
 Moose::Exporter->setup_import_methods(
     with_caller => [qw(events)],
     also        => [qw(Moose)],
@@ -36,11 +39,17 @@ sub events {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Moses::Plugin - Sugar for Plugins
+Moses::Plugin - Sugar for Moses Plugins
+
+=head1 VERSION
+
+version 0.90
 
 =head1 DESCRIPTION
 
@@ -56,16 +65,31 @@ Insert description of subroutine here...
 
 =head1 BUGS AND LIMITATIONS
 
-None known currently, please email the author if you find any.
+None known currently, please report bugs to L<https://rt.cpan.org/Ticket/Create.html?Queue=Adam>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Chris Prather (chris@prather.org)
+=over 4
 
-=head1 LICENCE
+=item *
 
-Copyright 2007-2009 by Chris Prather.
+Chris Prather <chris@prather.org>
 
-This software is free.  It is licensed under the same terms as Perl itself.
+=item *
+
+Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Chris Prather, Torsten Raudssus.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
